@@ -48,6 +48,8 @@ BayonneBinder("ivrscript1")
                 {"assign", false, (Method)&ScriptMethods::scrNop,
                         (Check)&Checks::chkAssign},    
                 {"register", false, (Method)&ScriptMethods::scrNop,
+                        (Check)&Checks::chkRegister},
+                {"extern", false, (Method)&ScriptMethods::scrNop,
                         (Check)&Checks::chkRegister}, 
                 {"key", true, (Method)&Methods::scrKey,
                         (Check)&Checks::chkKey},  
