@@ -153,7 +153,7 @@ const char *Checks::chkRegister(Line *line, ScriptImage *img)
 	if(ext && !stricmp(ext, ".conf"))
 	{
 		if(cp)
-			return "cannot register to to alternate in config";
+			return "cannot register to alternate in config";
 
 		cp = strrchr(scr->filename, '/');
 		if(cp)
@@ -161,7 +161,7 @@ const char *Checks::chkRegister(Line *line, ScriptImage *img)
 		else
 			cp = scr->filename;
 
-		setString(dbuf, sizeof(dbuf), scr->filename);
+		setString(dbuf, sizeof(dbuf), cp);
 		sp = strchr(dbuf, '.');
 		if(sp)
 			*sp = 0;
