@@ -20,6 +20,7 @@
 using namespace ost;
 using namespace std;
 
+unsigned long Bayonne::Traffic::stamp = 0;
 ScriptImage **Bayonne::localimages = NULL;
 BayonneSession **Bayonne::timeslots = NULL;
 Bayonne::timeslot_t Bayonne::ts_count = 0;
@@ -34,6 +35,8 @@ char *Bayonne::status = NULL;
 timeout_t Bayonne::step_timer = 20;
 timeout_t Bayonne::reset_timer = 60;
 timeout_t Bayonne::exec_timer = 60000;
+Bayonne::Traffic Bayonne::total_call_attempts;
+Bayonne::Traffic Bayonne::total_call_complete;
 Mutex Bayonne::serialize;
 char Bayonne::sla[64] = {0};
 unsigned Bayonne::idle_count = 0;
@@ -43,6 +46,7 @@ time_t Bayonne::start_time = 0;
 AtomicCounter Bayonne::libexec_count = 0;
 unsigned Bayonne::compile_count;
 volatile bool Bayonne::image_loaded = false;
+volatile unsigned short Bayonne::total_active_calls = 0;
 
 Audio::Encoding Bayonne::peer_encoding = Audio::unknownEncoding;
 Audio::timeout_t Bayonne::peer_framing = 0;
@@ -88,6 +92,18 @@ Bayonne::statetab Bayonne::states[] = {
 	{"final", &BayonneSession::stateFinal, ' '},
 	{NULL, NULL, ' '}};
 
+Bayonne::Traffic::Traffic()
+{
+	time_t ts;
+	if(!stamp)
+	{
+		time(&ts);
+		stamp = (unsigned long)ts;
+	}
+
+	iCount = oCount = 0;
+}
+
 bool Bayonne::getUserdata(void)
 {
 #ifdef	WIN32
