@@ -150,7 +150,8 @@ public:
 		PICKUP,		/* station pickup */
 		FORWARDED,	/* inbound forwarded call */
 		RECALL,		/* inbound hold recall */
-		DIRECT		/* node/endpoint direct */
+		DIRECT,		/* node/endpoint direct */
+		VIRTUAL		/* virtual channel driver */
 	}	calltype_t;
 
 	/**
@@ -474,6 +475,10 @@ public:
                 const char *userid;
                 const char *type;
                 const char *status;
+		unsigned short active_calls, call_limit;
+		unsigned long attempts_iCount, attempts_oCount;
+		unsigned long complete_iCount, complete_oCount;
+		time_t updated;
         }	regauth_t;
 
 	/**
@@ -553,6 +558,24 @@ public:
 
 	}	Event;
 
+	/**
+	 * This is a class used for collecting statistics for call 
+	 * traffic measurement, such as might be used by MRTG.
+	 */
+	class Traffic
+	{
+	private:
+		static unsigned long stamp;
+
+	public:
+		Traffic();
+
+		static inline unsigned long getStamp(void)
+			{return stamp;};
+
+		volatile unsigned long iCount, oCount;
+	};
+
 	/**
 	 * The current state handler in effect for a given channel
 	 * to receive events.  This is done by a direct method pointer
@@ -690,6 +713,13 @@ public:
 	 */
 	static Mutex serialize;
 
+	/**
+	 * master traffic counters for call attempts and call completions.
+	 */
+	static Traffic total_call_attempts;
+	static Traffic total_call_complete;
+	static volatile unsigned short total_active_calls;
+
 	/**
 	 * Allocates the maximum number of timeslots the server will use as
 	 * a whole and attaches a given server to the library.
@@ -1355,6 +1385,9 @@ protected:
 	void relistIdle(void);
 
 public:
+	Traffic call_attempts, call_complete;
+	volatile unsigned short active_calls;
+
 	/**
 	 * Create a driver instance.
 	 *
@@ -1728,6 +1761,9 @@ protected:
 	timeslot_t timeslot, count, used;	// timeslots
 
 public:
+	Traffic call_attempts, call_complete;
+	volatile unsigned short active_calls;
+
 	/**
 	 * Create a span for a specified number of timeslots.
 	 *
@@ -2006,7 +2042,21 @@ protected:
 
 	const char *getWritepath(char *buf = NULL, size_t len = 0);
 
+	void incIncomingAttempts(void);
+
+	void incOutgoingAttempts(void);
+
+	void incIncomingComplete(void);
+
+	void incOutgoingComplete(void);
+
+	void incActiveCalls(void);
+
+	void decActiveCalls(void);
+
 public:
+	Traffic call_attempts, call_complete;
+
 	/**
 	 * Process interpreter session symbols.
 	 *
