@@ -97,28 +97,61 @@ BayonneSession::~BayonneSession()
 	finalize();
 }
 
-/* Script::Name *BayonneSession::getScript(const char *scr)
+void BayonneSession::incIncomingAttempts(void)
 {
-	ScriptImage **img;
+	incActiveCalls();
 
-	printf("GET SCRIPT!!!! %s\n", scr);
+	++call_attempts.iCount;
+	++total_call_attempts.iCount;
+	++driver->call_attempts.iCount;
+	if(span)
+		++span->call_attempts.iCount;
+}
 
-	if(!strnicmp(scr, "_local_::", 9))
-	{
-		printf("LOCAL!\n");
-		img = getLocalImage(timeslot);
-		if(!img)
-			return NULL;
+void BayonneSession::decActiveCalls(void)
+{
+	--total_active_calls;
+	--driver->active_calls;
+	if(span)
+		--span->active_calls;
+}
 
-		if(!*img)
-			return NULL;
+void BayonneSession::incActiveCalls(void)
+{
+        ++total_active_calls;
+        ++driver->active_calls;
+        if(span)
+                ++span->active_calls;
+}
 
-		return (*img)->getScript(scr);
-	}
+void BayonneSession::incOutgoingAttempts(void)
+{
+	incActiveCalls();
 
-	return ScriptInterp::getScript(scr);
-} 
-*/
+	++call_attempts.oCount;
+	++total_call_attempts.oCount;
+	++driver->call_attempts.oCount;
+	if(span)
+		++span->call_attempts.oCount;
+}
+
+void BayonneSession::incIncomingComplete(void)
+{
+	++call_complete.iCount;
+        ++total_call_complete.iCount;
+        ++driver->call_complete.iCount;
+        if(span)
+                ++span->call_complete.iCount;
+}
+
+void BayonneSession::incOutgoingComplete(void)
+{
+	++call_complete.oCount;
+        ++total_call_complete.oCount;
+        ++driver->call_complete.oCount;
+        if(span)
+                ++span->call_complete.oCount;
+}
 
 void BayonneSession::initialize(void)
 {
@@ -436,6 +469,8 @@ const char *BayonneSession::getExternal(const char *id)
 				return "recall";
 			case PICKUP:
 				return "pickup";
+			case VIRTUAL:
+				return "virtual";
 			}
 		}
 		else if(!stricmp(id, "interface"))
