@@ -1551,6 +1551,9 @@ attach:
 
 bool BayonneSession::statePickup(Event *event)
 {
+	if(event->id == ENTER_STATE)
+		incIncomingAttempts();
+
 	if(enterPickup(event))
 		return true;
 
@@ -1580,6 +1583,9 @@ bool BayonneSession::stateSeize(Event *event)
 {
 	char evtname[96];
 
+	if(event->id == ENTER_STATE)
+		incOutgoingAttempts();
+
 	if(enterSeize(event))
 		return true;
 
@@ -1729,6 +1735,15 @@ bool BayonneSession::stateRunning(Event *event)
 			if(seizure != CHILD_RUNNING)
 				strcpy(var_pid, "none");
 			setConst("session.callref", var_sid);
+			switch(type)
+			{
+			case OUTGOING:
+				incOutgoingComplete();
+			case VIRTUAL:
+				break;
+			default:
+				incIncomingComplete();
+			}			
 		}
 		if(state.pid)
 			newTid();
@@ -1780,6 +1795,9 @@ bool BayonneSession::stateHangup(Event *event)
 	Event pe;
 	BayonneSession *parent = NULL;
 
+	if(event->id == ENTER_STATE)
+		decActiveCalls();
+
         if(enterHangup(event))
                 return true; 
 
