@@ -80,6 +80,9 @@ Driver Driver::sip;
 
 bool Registry::isActive(void)
 {
+	if(!stricmp(type, "anon"))
+		return true;
+
 	if(!proxy)
 		return false;
 
@@ -249,7 +252,15 @@ Thread(atoi(getLast("priority")), atoi(getLast("stack")) * 1024 + 8192)
 	else
 		info.setFraming(atol(getLast("framing")));
 	registry = false;
-	server->setValue("sip.conf", CONFIG_FILES "/sip.conf");
+	cp = server->getLast("serverconfig");
+	if(cp)
+	{
+		snprintf(buf, sizeof(buf), "%s/%s/sip.conf",
+			CONFIG_FILES, cp);
+		server->setValue("sip.conf", buf);
+	}
+	else
+		server->setValue("sip.conf", CONFIG_FILES "/sip.conf");
 }
 
 unsigned Driver::getRegistration(regauth_t *data, unsigned count)
@@ -260,13 +271,21 @@ unsigned Driver::getRegistration(regauth_t *data, unsigned count)
 
 	while(idx < count && reg)
 	{
-		if(!strnicmp(reg->proxy, "sip:", 4))
+		if(!stricmp(reg->type, "anon"))
+			data[idx].remote = "*";
+		else if(!strnicmp(reg->type, "ext", 3) && !reg->active)
+			data[idx].remote = "-";
+		else if(!strnicmp(reg->proxy, "sip:", 4))
 			data[idx].remote = reg->proxy + 4;
 		else
 			data[idx].remote = reg->proxy;
 		data[idx].userid = reg->userid;
 		data[idx].type = reg->type;
-		if(!reg->proxy || !reg->userid)
+		if(!stricmp(reg->type, "anon"))
+			data[idx].status = "active";
+		else if(!strnicmp(reg->type, "ext", 3) && !reg->active)
+			data[idx].status = "offline";
+		else if(!reg->proxy || !reg->userid)
 			data[idx].status = "invalid";
 		else if(!reg->active)
 			data[idx].status = "failed";
@@ -274,6 +293,13 @@ unsigned Driver::getRegistration(regauth_t *data, unsigned count)
 			data[idx].status = "active";
 		else
 			data[idx].status = "expired";
+		data[idx].updated = reg->updated;
+		data[idx].attempts_iCount = reg->call_attempts.iCount;
+		data[idx].attempts_oCount = reg->call_attempts.oCount;
+		data[idx].complete_iCount = reg->call_complete.iCount;
+		data[idx].complete_oCount = reg->call_complete.oCount;
+		data[idx].active_calls = reg->active_calls;
+		data[idx].call_limit = reg->call_limit;
 		++idx;
 		reg = reg->next;
 	}
@@ -515,6 +541,7 @@ const char *Driver::assignScript(ScriptImage *img, Line *line)
 			break;
 
 		reg = (Registry *)img->getMemory(sizeof(Registry));
+		memset(reg, 0, sizeof(Registry));
 		reg->add(img);
 		reg->proxy = NULL;
 		reg->active = true;
@@ -530,6 +557,7 @@ const char *Driver::assignScript(ScriptImage *img, Line *line)
 		reg->secret = NULL;
 		reg->line = line;
 		reg->duration = 0;		
+		reg->updated = 0;
 
 		setString(cbuf, sizeof(cbuf), scr->name);
 		ep = strchr(cbuf, ':');
@@ -744,11 +772,7 @@ fail401:
 	}
 
 sip200:
-	server->leave();
 	eXosip_lock();	
-	eXosip_message_build_answer(sevent->tid, 200, &reply);
-	eXosip_message_send_answer(sevent->tid, 200, reply);
-
 	osip_message_get_expires(sevent->request, 0, &exp);
 	if(exp && exp->hvalue)
 		pos = osip_atoi(exp->hvalue);
@@ -760,16 +784,24 @@ sip200:
 	eXosip_unlock();
 	if(pos)
 	{
+		time(&reg->updated);
 		reg->setTimer(pos * 1000);
 		reg->active = true;
 		slog.debug("registered external %s from %s; expires=%d", auth->username, buf, pos);
 	}
 	else
 	{
+		reg->updated = 0l;
 		reg->active = false;
 		reg->setTimer(0);
 		slog.debug("unregister external %s from %s", auth->username, buf);
 	}
+	server->leave();
+
+        eXosip_lock();
+        eXosip_message_build_answer(sevent->tid, 200, &reply);
+        eXosip_message_send_answer(sevent->tid, 200, reply);
+	eXosip_unlock();
 	return;
 
 challenge:
@@ -797,16 +829,24 @@ const char *Driver::registerScript(ScriptImage *img, Line *line)
 	InetAddress host;
 	bool ext = false;
 
+	memset(reg, 0, sizeof(Registry));
+
 	if(!strnicmp(line->cmd, "ext", 3))
 		ext = true;
 
 	if(ext)
-		if(!ScriptChecks::useKeywords(line, "=secret=encoding=framing=dtmf"))
-			return "invalid keywords used for external";
+	{
+		if(!ScriptChecks::useKeywords(line, 
+			"=secret=encoding=framing=dtmf=forward"))
+				return "invalid keywords used for sip external";
+	}
 
-	if(!ScriptChecks::useKeywords(line, "=uri=timeout=server=proxy=userid=secret=type=realm=dtmf=public=encoding=framing"))
-		return "invalid keywords for sip, use uri, timeout, proxy, userid, secret, port";
+	if(!ScriptChecks::useKeywords(line, 
+		"=uri=timeout=server=proxy=userid=secret=type=realm=dtmf"
+		"=limit=public=encoding=framing=forward"))
+			return "invalid keywords for sip registry";
 
+	reg->updated = 0l;
 	reg->active = false;
 	reg->protocol = "sip";
 	reg->iface = getLast("interface");
@@ -819,6 +859,11 @@ const char *Driver::registerScript(ScriptImage *img, Line *line)
 	reg->type = ScriptChecks::findKeyword(line, "type");
 	reg->dtmf = ScriptChecks::findKeyword(line, "dtmf");
 	reg->encoding = ScriptChecks::findKeyword(line, "encoding");
+	reg->forward = ScriptChecks::findKeyword(line, "forward");
+
+	cp = ScriptChecks::findKeyword(line, "limit");
+	if(cp)
+		reg->call_limit = atoi(cp);
 
 	cp = ScriptChecks::findKeyword(line, "framing");
 	if(!cp || !reg->encoding)
@@ -960,6 +1005,14 @@ const char *Driver::registerScript(ScriptImage *img, Line *line)
 	if(!reg->uri)
 		reg->uri = uri;
 
+	if(!strnicmp(reg->type, "anon", 4))
+	{
+		reg->type = "anon";
+		slog.debug("register %s for anonymous calling", reg->localid);
+		img->setValue("sip.anonymous", reg->localid);
+		goto add;
+	}
+
 	if(!stricmp(reg->type, "node") || !strnicmp(reg->type, "ext", 3))
 	{
 		reg->type = "extern";
@@ -1594,6 +1647,16 @@ killit:
 
 			if(!reg && !peer)
 			{
+				cp = img->getLast("sip.anonymous");
+				if(cp)
+				{
+					snprintf(buf, sizeof(buf), 
+						"uri.%s", cp);
+					reg = (Registry *)img->getPointer(buf);
+					if(reg && !stricmp(reg->type, "anon"))
+						goto validate;
+					reg = NULL;
+				}								
 				endImage(img);
 				requestAuth(sevent);
 				goto clear;
@@ -1611,6 +1674,9 @@ validate:
 			{
 				if(!reg->isActive())
 					goto sip404;
+	
+				if(reg->call_limit && reg->active_calls >= reg->call_limit)
+					goto sip480;
 
 				scr = img->getScript(reg->scr->name);
 				cp = reg->dtmf;
@@ -1648,6 +1714,7 @@ sip401:
 			if(!s)
 			{
 				slog.warn("sip: no timeslots available");
+sip480:
 				endImage(img);
 				eXosip_lock();
 				eXosip_call_send_answer(sevent->tid, 480, NULL);
@@ -1699,7 +1766,13 @@ sip401:
 
 			if(reg)
 			{
-				snprintf(cbuf, sizeof(cbuf), "sipreg.%d", reg->regid);
+				++reg->active_calls;
+				++reg->call_attempts.iCount;
+				++reg->call_complete.iCount;
+				if(!stricmp(reg->type, "anon") || !strnicmp(reg->type, "ext", 3))
+					snprintf(cbuf, sizeof(cbuf), "uri.%s", reg->localid);
+				else
+					snprintf(cbuf, sizeof(cbuf), "sipreg.%d", reg->regid);
 				session->setConst("session.registry", cbuf);
 				session->setConst("session.uri_server", reg->proxy);
 				session->setConst("session.uri_local", reg->contact);
