@@ -87,9 +87,14 @@ public:
 	const char *realm;
 	const char *dtmf;
 	const char *encoding;
+	const char *forward;
 	timeout_t framing;
 	int regid;
 	bool active;
+	time_t updated;
+	Bayonne::Traffic call_attempts, call_complete;
+	volatile short active_calls;
+	short call_limit;
 
 	bool isActive(void);
 	void add(ScriptImage *img);
