@@ -287,12 +287,32 @@ bool Session::enterSeize(Event *event)
 			return false;
 		}
 		route = Driver::sip.getLast("outbound");
-		if(!strchr(cp, '@'))
+forward:
+		if(!strchr(cp, '@') && !route)
 		{
 			snprintf(buf, sizeof(buf), "uri.%s", cp);
 			reg = (Registry *)img->getPointer(buf);
-			if(reg && !strnicmp(reg->type, "ext", 3))
+			if(reg)
 			{
+				if(!reg->isActive())
+				{
+					cp = reg->forward;
+					if(cp)
+						goto forward;
+
+					event->id = DIAL_FAILED;
+					return false;
+				}
+				if(!stricmp(reg->type, "anon"))
+				{
+					event->id = DIAL_FAILED;
+					return false;
+				}
+				if(reg->call_limit && reg->active_calls >= reg->call_limit)
+				{
+					event->id = DIAL_BUSY;
+					return false;
+				}
 				snprintf(buf, sizeof(buf), "sip:%s@%s",
 					reg->userid, reg->proxy);
 				if(!route)
@@ -303,6 +323,11 @@ bool Session::enterSeize(Event *event)
 				setConst("session.uri_remote", buf);
 				goto dialing;
 			}
+			else
+			{
+				event->id = DIAL_FAILED;
+				return false;
+			}
 		}
 		if(!strchr(cp, '@'))
 			snprintf(buf, sizeof(buf), "sip:%s@%s", cp, route);
@@ -335,7 +360,16 @@ dialing:
 
 			if(!route)
 				route = reg->proxy;
-			snprintf(rbuf, sizeof(rbuf), "sipreg.%d", reg->regid);
+
+			++reg->active_calls;
+			++reg->call_attempts.oCount;
+			++reg->call_complete.oCount;
+			if(!strnicmp(reg->type, "ext", 3))
+				snprintf(rbuf, sizeof(rbuf), 
+					"uri.%s", reg->localid);
+			else
+				snprintf(rbuf, sizeof(rbuf), 
+					"sipreg.%d", reg->regid);
 			setConst("session.registry", rbuf);
 			setConst("session.uri_server", reg->proxy);
 			setConst("session.uri_local", reg->contact);
@@ -502,8 +536,21 @@ failure:
 
 bool Session::enterHangup(Event *event)
 {
+	ScriptImage *img = getImage();
+	Registry *reg;
+	const char *cp;
+
 	switch(event->id)
 	{
+	case ENTER_STATE:
+		cp = getSymbol("session.registry");
+		printf("SESSION HANGUP REG %s\n", cp);
+		if(!cp)
+			break;
+		reg = (Registry *)img->getPointer(cp);
+		if(reg)
+			--reg->active_calls;	
+		break;
 	case TIMER_EXPIRED:
 		if(!rtp_flag)
 			break;
