@@ -50,13 +50,14 @@ public:
 class Keyboard : public Thread, public Bayonne
 {
 private:
+	timeslot_t ts;
 
 #ifndef	WIN32
 	termios t;	// saved termios to restore on exiting
 #endif
 
 public:
-	Keyboard(Driver *driver);
+	Keyboard(timeslot_t ts);
 	~Keyboard();
 
 	void run(void);
