@@ -41,14 +41,8 @@ public:
 	RPCServer();
 }	sunrpc;
 
-#ifdef  WIN32
-#define KEYS    "/bayonne/sunrpc"
-#else
-#define KEYS    "/bayonne/module/sunrpc"
-#endif
-
 RPCServer::RPCServer() :
-BayonneService(-1, 0), Keydata(Bayonne::getKeypath(KEYS))
+BayonneService(-1, 0), Keydata("/bayonne/module/sunrpc")
 {
 	static Keydata::Define defkeys[] = {
 	{"protocols", "tcp udp"},
