@@ -39,7 +39,7 @@
 
 #endif
 
-namespace module {
+namespace moduleTCP {
 using namespace ost;
 using namespace std;
 
