@@ -242,46 +242,107 @@ void Session::htmlStatus(void)
 	BayonneDriver *d = BayonneDriver::getPrimary();
 	unsigned count;
 	regauth_t *r;
+	char dbuf[33];
+	char abuf[33];
+	time_t tb;
 
+	time(&tb);
 	htmlHeader("Bayonne Status", true);
 	sendText("<H1>Bayonne Status</H1><P>\r\n");
 
 	sendText("<TABLE border=\"1\" summary=\"Installed Drivers\">\r\n");
 	sendText("<CAPTION><EM>Drivers loaded into server</EM></CAPTION>\r\n");
-	sendText("<TR><TH rowspan=\"2\">Name<TH colspan=\"2\">Timeslots<TH colspan=\"2\">Spans\r\n");
-	sendText("<TR><TH>first<TH>count<TH>first<TH>count\r\n");
+	sendText("<TR><TH rowspan=\"2\">Name"
+		"<TH colspan=\"3\">Timeslots"
+		"<TH colspan=\"2\">Spans"
+		"<TH colspan=\"2\">Total"
+		"<TH colspan=\"2\">Completed\r\n");
+	sendText("<TR><TH>first<TH>count<TH>active<TH>first<TH>count"
+		"<TH>incoming<TH>outgoing<TH>incoming<TH>outgoing\r\n");
 	while(d)
 	{
-		snprintf(buffer, sizeof(buffer), "<TR><TD>%s<TD>%d<TD>%d<TD>%d<TD>%d\r\n",
+		snprintf(buffer, sizeof(buffer), 
+			"<TR><TD>%s<TD>%d<TD>%d<TD>%d<TD>%d<TD>%d"
+			"<TD>%lu<TD>%lu<TD>%lu<TD>%lu\r\n",
 			d->getName(), (int)d->getFirst(), (int)d->getCount(),
- 			(int)d->getSpanFirst(), (int)d->getSpansUsed());
+			(int)d->active_calls,
+ 			(int)d->getSpanFirst(), (int)d->getSpansUsed(),
+			d->call_attempts.iCount, d->call_attempts.oCount,
+			d->call_complete.iCount, d->call_complete.oCount);
 
 		sendText(buffer);
 		d = d->getNext();
 	}	
-	sendText("</TABLE>\r\n");
+	sendText("</TABLE><BR>\r\n");
 
 	d = BayonneDriver::getPrimary();
 	sendText("<TABLE border=\"1\" summary=\"Server Registrations\">\r\n");
 	sendText("<CAPTION><EM>Server Registrations</EM></CAPTION>\r\n");
-	sendText("<TR><TH>Remote<TH>User<TH>Type<TH>Status\r\n");
+	sendText("<TR><TH>Remote<TH>User<TH>Type<TH>Status"
+		"<TH>Refresh<TH>Incoming<TH>Outgoing<TH>active\r\n");
 	while(d)
 	{
 		count = d->getRegistration(regs, 1024);
 		r = regs;
 		while(count--)
 		{
+			if(r->updated)
+			{
+				r->updated = (unsigned long)tb - r->updated;
+				snprintf(dbuf, sizeof(dbuf), "%02ld:%02ld:%02ld",
+					r->updated / 3600,
+					(r->updated / 60) % 60,
+					r->updated % 60);
+			}
+			else
+				strcpy(dbuf, "-");
+
+			if(r->call_limit)
+				snprintf(abuf, sizeof(abuf), "%u/%u", 
+					(int)r->active_calls, (int)r->call_limit);
+			else
+				snprintf(abuf, sizeof(abuf), "%u/-",
+					(int)r->active_calls);
+
 			snprintf(buffer, sizeof(buffer),
-				"<TR><TD>%s<TD>%s<TD>%s<TD>%s\r\n",
-				r->remote, r->userid, r->type, r->status);
+				"<TR><TD>%s<TD>%s<TD>%s<TD>%s"
+				"<TD>%s<TD>%lu<TD>%lu<TD>%s\r\n",
+				r->remote, r->userid, r->type, r->status,
+				dbuf, 
+				r->attempts_iCount,
+				r->attempts_oCount,
+				abuf);
 			sendText(buffer);
 			++r;
 		} 
 		d = d->getNext();
 	}
-	sendText("</TABLE>\r\n");
+	sendText("</TABLE><BR>\r\n");
 
-	snprintf(buffer, sizeof(buffer), "Activity: %s<BR>\r\n", Bayonne::status);
+        snprintf(buffer, sizeof(buffer),
+                "Completed incoming calls: %lu<BR>\r\n",
+                Bayonne::total_call_complete.iCount);
+        sendText(buffer);
+        snprintf(buffer, sizeof(buffer),
+                "Completed outgoing calls: %lu<BR>\r\n",
+                Bayonne::total_call_complete.oCount);
+	sendText(buffer);
+
+	snprintf(buffer, sizeof(buffer), 
+		"Total incoming calls: %lu<BR>\r\n", 
+		Bayonne::total_call_attempts.iCount);
+	sendText(buffer);
+	snprintf(buffer, sizeof(buffer), 
+		"Total outgoing calls: %lu<BR>\r\n", 
+		Bayonne::total_call_attempts.oCount);
+	sendText(buffer);
+
+	snprintf(buffer, sizeof(buffer),
+		"Total active calls: %u<BR>\r\n",
+		(int)Bayonne::total_active_calls);
+	sendText(buffer);
+
+	snprintf(buffer, sizeof(buffer), "<BR>Activity: %s<BR>\r\n", Bayonne::status);
 	sendText(buffer);
 
 	htmlFooter();	
