@@ -49,7 +49,10 @@ void Session::xmlFault(int code, const char *string)
 	char msg[96];
 	const char *svc = string;
 	snprintf(msg, sizeof(msg), "HTTP/1.1 %d %s\r\n", code, string);
-	sendError(msg, "text/xml");
+	if(code == 401)
+		sendAuth(msg, "text/xml");
+	else
+		sendError(msg, "text/xml");
 	sendText("<?xml version=\"1.0\"?>\r\n");
 	sendText("<serverResponse>\r\n");
 	if(code >= 300 && code <= 500)
@@ -199,9 +202,11 @@ void Session::xmlRegistrations(void)
 				"    <item id=\"userid\" value=\"%s\"/>\r\n"
 				"    <item id=\"access\" value=\"%s\"/>\r\n"
 				"    <item id=\"status\" value=\"%s\"/>\r\n"
+				"    <item id=\"active\" value=\"%d\"/>\r\n"
 				"   </list>\r\n",
 				d->getName(),
-				r->remote, r->userid, r->type, r->status);
+				r->remote, r->userid, r->type, r->status,
+				(int)r->active_calls);
 			sendText(buffer);
 			++r;
 		}
@@ -223,12 +228,21 @@ void Session::xmlDrivers(void)
 			"    <item id=\"driver\" value=\"%s\"/>\r\n"
 			"    <item id=\"firstTimeslot\" value=\"%d\"/>\r\n"
 			"    <item id=\"countTimeslots\" value=\"%d\"/>\r\n"
+			"    <item id=\"activeTimeslots\" value=\"%d\"/>\r\n"
 			"    <item id=\"firstSpan\" value=\"%d\"/>\r\n"
 			"    <item id=\"countSpans\" value=\"%d\"/>\r\n"
+			"    <item id=\"incomingAttempts\" value=\"%lu/>\r\n"
+                        "    <item id=\"outgoingAttempts\" value=\"%lu/>\r\n"
+                        "    <item id=\"incomingComplete\" value=\"%lu/>\r\n"
+                        "    <item id=\"outgoingComplete\" value=\"%lu/>\r\n"
+
 			"   </list>\r\n",
 			d->getName(),
 			(int)d->getFirst(), (int)d->getCount(),
-			(int)d->getSpanFirst(), (int)d->getSpansUsed());
+			(int)d->active_calls,
+			(int)d->getSpanFirst(), (int)d->getSpansUsed(),
+			d->call_attempts.iCount, d->call_attempts.oCount,
+                        d->call_complete.iCount, d->call_complete.oCount);
 		sendText(buffer);
 		d = d->getNext();
 	}
@@ -320,6 +334,41 @@ void Session::xmlStatus(void)
 	xmlFooter();
 }
 
+void Session::xmlTraffic(void)
+{
+	xmlHeader("traffic");
+	snprintf(buffer, sizeof(buffer),
+		"  <result id=\"timestamp\" value=\"%lu\"/>\r\n", 
+			Bayonne::Traffic::getStamp());
+	sendText(buffer);
+        snprintf(buffer, sizeof(buffer),
+                "  <result id=\"incomingAttempts\" value=\"%lu\"/>\r\n",
+                        Bayonne::total_call_attempts.iCount);
+        sendText(buffer);
+
+        snprintf(buffer, sizeof(buffer),
+                "  <result id=\"outgoingAttempts\" value=\"%lu\"/>\r\n",
+                        Bayonne::total_call_attempts.oCount);
+        sendText(buffer);
+
+        snprintf(buffer, sizeof(buffer),
+                "  <result id=\"incomingComplete\" value=\"%lu\"/>\r\n",
+                        Bayonne::total_call_complete.iCount);
+        sendText(buffer);
+	
+	snprintf(buffer, sizeof(buffer),
+		"  <result id=\"outgoingComplete\" value=\"%lu\"/>\r\n",
+			Bayonne::total_call_complete.oCount);
+	sendText(buffer);
+
+        snprintf(buffer, sizeof(buffer),
+                "  <result id=\"activeCalls\" value=\"%u\"/>\r\n",
+                        (int)Bayonne::total_active_calls);
+        sendText(buffer);
+
+	xmlFooter();
+}
+
 void Session::xmlTimeslots(void)
 {
 	xmlHeader("timeslots");
